References
----------

.. [Angerer16] Angerer *et al.* (2016),
   *destiny – diffusion maps for large-scale single-cell data in R*,
   `Bioinformatics <https://doi.org/10.1093/bioinformatics/btv715>`__.
   
.. [Cusanovich18] Cusanovich, D. A. et al. A Single-Cell Atlas of In Vivo 
   Mammalian Chromatin Accessibility. Cell 174, 1309–1324.e18 (2018).
   
.. [Luo17] Luo, C. et al. Single-cell methylomes identify neuronal subtypes
   and regulatory elements in mammalian cortex. Science 357, 600–604 (2017).
   
.. [Wolf18] Wolf, F. A., Angerer, P. & Theis, F. J. SCANPY: large-scale
   single-cell gene expression data analysis. Genome Biol. 19, 15 (2018).

.. [Buenrostro18] Buenrostro J. D. et al. Integrated Single-Cell Analysis
	Maps the Continuous Regulatory Landscape of Human Hematopoietic
	Differentiation. Cell 173 (2018)